==> mcmsupply_0.1.1.tar.gz: mcmsupply/inst/doc/package_data.R <==
## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)

## ---- include=TRUE, message=FALSE---------------------------------------------
library(mcmsupply)

## -----------------------------------------------------------------------------
Country_and_area_classification
??Country_and_area_classification

## -----------------------------------------------------------------------------
country_names
??country_names

## -----------------------------------------------------------------------------
estimated_national_correlations

## -----------------------------------------------------------------------------
estimated_global_subnational_correlations

## -----------------------------------------------------------------------------
median_alpha_region_intercepts

## -----------------------------------------------------------------------------
precision_alpha_country_intercepts

## -----------------------------------------------------------------------------
Bspline_sigma_matrix_median

## -----------------------------------------------------------------------------
median_alphacms

## -----------------------------------------------------------------------------
mcmsupply::tau_alphapms_subnationalmod

## -----------------------------------------------------------------------------
 mcmsupply::inv.sigma_delta_hat_subnationalmod

## -----------------------------------------------------------------------------
national_FPsource_data

## -----------------------------------------------------------------------------
subnat_FPsource_data

==> mcmsupply_0.2.2.tar.gz: mcmsupply/inst/doc/package_data.R <==
## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)

## ---- include=TRUE, message=FALSE---------------------------------------------
library(mcmsupply)

## -----------------------------------------------------------------------------
head(national_FPsource_data)

## -----------------------------------------------------------------------------
head(subnat_FPsource_data)


## -----------------------------------------------------------------------------
Country_and_area_classification
??Country_and_area_classification

## -----------------------------------------------------------------------------
country_names
??country_names

## -----------------------------------------------------------------------------
national_estimated_correlations_logitnormal

## -----------------------------------------------------------------------------
subnational_estimated_correlations

## -----------------------------------------------------------------------------
national_theta_rms_hat_logitnormal

## -----------------------------------------------------------------------------
national_tau_alpha_cms_hat_logitnormal

## -----------------------------------------------------------------------------
national_sigma_delta_hat_logitnormal

## -----------------------------------------------------------------------------
subnational_alpha_cms_hat

## -----------------------------------------------------------------------------
subnational_tau_alpha_pms_hat

## -----------------------------------------------------------------------------
subnational_inv.sigma_delta_hat
